@@ -17,7 +17,7 @@ from .. import __version__
 from ..exceptions import QueryError
 from ..formatters.csv import Formatter as CsvFormatter
 from ..plugin import BaseCommand, get_installed_functions
-from ..query import Query
+from ..query import Executor
 from ..types import QueryDefinition
 from ..utils import get_config_dir
 
@@ -40,15 +40,25 @@ class Command(BaseCommand):
         parser.add_argument(
             "--editor-mode", "-m", choices=["emacs", "vi"], default=None,
         )
+        parser.add_argument(
+            "--disable-progressbars",
+            action="store_false",
+            default=True,
+            dest="enable_progressbars",
+        )
 
     def _prompt_loop(self, session: PromptSession):
         viewer: str = cast(str, self.config.get("viewers", {}).get("csv")) or "vd"
 
-        result = session.prompt("Query > ")
+        result = session.prompt(">>> ")
 
         try:
             query_definition: QueryDefinition = safe_load(result)
-            query = Query(self.jira, query_definition, progress_bar=True)
+            query = Executor(
+                self.jira,
+                query_definition,
+                progress_bar=self.options.enable_progressbars,
+            )
         except Exception as e:
             raise QueryParseError(e)
 
@@ -72,6 +82,7 @@ class Command(BaseCommand):
             "sort_by",
             "expand",
             "limit",
+            "cap",
         ]
         function_completions = list(get_installed_functions(self.jira).keys())
         field_completions = [field["id"] for field in self.jira.fields()]
@@ -88,14 +99,13 @@ class Command(BaseCommand):
             vi_mode = self.options.editor_mode
         if vi_mode:
             self.console.print(
-                " [Press ESC followed by ENTER to run query.]",
-                style="deep_sky_blue4",
-                markup=False,
+                " | [bold]Run:[/bold]\t\tESC->ENTER", style="deep_sky_blue4",
             )
             self.console.print(
-                " [Press CTRL+D from an empty prompt to exit.]",
-                style="grey30",
-                markup=False,
+                " | [bold]Clear:[/bold]\tCTRL+C", style="deep_sky_blue4",
+            )
+            self.console.print(
+                " | [bold]Exit:[/bold]\tCTRL+D", style="deep_sky_blue4",
             )
 
         completions = self.build_completions()
