@@ -5,7 +5,17 @@ import logging
 import os
 import re
 from types import ModuleType
-from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Union, Tuple
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Dict,
+    List,
+    Optional,
+    Union,
+    Tuple,
+    Mapping,
+)
 
 from appdirs import user_config_dir
 from jira.resources import Resource
@@ -14,7 +24,7 @@ from simpleeval import EvalWithCompoundTypes
 from yaml import safe_dump, safe_load
 
 from .constants import APP_NAME
-from .exceptions import QueryError, JiraSelectError
+from .exceptions import FieldNameError, QueryError, JiraSelectError
 from .types import (
     ConfigDict,
     ExpressionList,
@@ -40,9 +50,9 @@ def get_config_dir() -> str:
     return root_path
 
 
-def get_cache_path() -> str:
+def get_cache_path(subcache: str = "default") -> str:
     config_path = get_config_dir()
-    cache_path = os.path.join(config_path, "cache")
+    cache_path = os.path.join(config_path, "cache", subcache)
     os.makedirs(cache_path, exist_ok=True)
 
     return cache_path
@@ -160,7 +170,13 @@ def evaluate_expression(
     expression: str,
     names: Dict[str, Any],
     functions: Optional[Dict[str, Callable]] = None,
+    interpolations: Optional[Mapping[str, Any]] = None,
 ) -> Any:
+    try:
+        expression = expression.format_map(interpolations or {})
+    except KeyError as e:
+        raise FieldNameError(e)
+
     return EvalWithCompoundTypes(names=names, functions=functions).eval(expression)
 
 
@@ -198,6 +214,7 @@ def get_field_data(
     row: Result,
     expression: str,
     functions: Optional[Dict[str, Callable]] = None,
+    interpolations: Optional[Mapping[str, Any]] = None,
     error_returns_null=True,
 ) -> Any:
     if functions is None:
@@ -206,9 +223,14 @@ def get_field_data(
     try:
         return normalize_value(
             evaluate_expression(
-                expression, names={"_": row, **row.as_dict()}, functions=functions,
+                expression,
+                names={"_": row, **row.as_dict()},
+                functions=functions,
+                interpolations=interpolations,
             )
         )
+    except FieldNameError as e:
+        raise QueryError(f"Field {e} does not exist.") from e
     except JiraSelectError:
         # Re-raise these -- they can be used for alerting the user
         # to a configuration problem or w/e
@@ -225,4 +247,4 @@ def get_field_data(
             raise
         return None
     except Exception as e:
-        raise QueryError(f"{e}: {expression}")
+        raise QueryError(f"{e}: {expression}") from e
